@@ -8,12 +8,31 @@ use warnings;
 
 # More or less the same as List::Util::uniqstr (or List::Util::uniq). Provided
 # here because the List::Util function is not available in 5.22 by default.
-sub uniqstr (@) {
-  my (@l) = @_;
-  for my $i (0 .. $#l - 1) {
-    undef $l[$i] if $l[$i] eq $l[$i+1];
+sub uniqstr {
+  my ($content, $markers) = @_;
+  for my $i (0 .. $#$content - 1) {
+    if ($content->[$i] eq $content->[$i+1]) {
+      undef $content->[$i];
+      undef $markers->[$i];
+    }
   }
-  return grep { defined } @l;
+  @$content = grep { defined } @$content;
+  @$markers = grep { defined } @$markers;
+}
+
+# Globally delete duplicate lines even if they are not contiguous. Keep the
+# first occurence of each string.
+sub globaluniqstr  {
+  my ($content, $markers) = @_;
+  my %seen;
+  for my $i (0 .. $#$content) {
+    if ($seen{$content->[$i]}++) {
+      undef $content->[$i];
+      undef $markers->[$i];
+    }
+  }
+  @$content = grep { defined } @$content;
+  @$markers = grep { defined } @$markers;
 }
 
 {
@@ -48,7 +67,9 @@ sub uniqstr (@) {
 }
 
 {
-  # A simple way to make a scalar be an alias of another one.
+  # A simple way to make a scalar be an alias of another one (but does not allow
+  # to store undef in the variable as this is used to mark non-existant lines
+  # in some function and this package is tied to the marker variable).
   package App::PTP::Util::AliasVar;
   sub TIESCALAR {
     my ($class) = @_;
@@ -61,7 +82,10 @@ sub uniqstr (@) {
   }
   sub STORE {
     my ($self, $value) = @_;
-    $$$self = $value;
+    # This empty string is also the value that is set in do_perl when the marker
+    # is undef (this is not the same as the default 0 that is put when the array
+    # is built).
+    $$$self = $value // '';
   }
   # Secret hidden methods for our usage only. These methods can't be used
   # through the tie-ed variable, but only through the object returned by the
@@ -74,7 +98,7 @@ sub uniqstr (@) {
 
 {
   # A fake array that returns the marker at a given offset from the current
-  # line.
+  # line (and refuses to store undef in the array).
   package App::PTP::Util::MarkersArray;
   our $NEGATIVE_INDICES = 1;
   sub TIEARRAY {
@@ -98,7 +122,7 @@ sub uniqstr (@) {
     my $index = ($$self->[1] - 1 + $offset);
     return $value if $index < 0;
     return $value if $index >= $self->FETCHSIZE();
-    $self->[0][$index] = $value;
+    $self->[0][$index] = $value // '';  # make it more difficult to store undef
   }
   sub STORESIZE {}
 }
